@@ -2,14 +2,14 @@
 """
 format-sql
 
-Copyright (c) 2014, Friedrich Paetzke (f.paetzke@gmail.com)
+Copyright (c) 2014, Friedrich Paetzke (paetzke@fastmail.fm)
 All rights reserved.
 
 """
-from .format_sql import format_sql
-from .formatter import pretty_format
+from .file_handling import format_file
+from .formatter import format_sql
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 __author__ = 'Friedrich Paetzke'
 __license__ = 'BSD'
 __copyright__ = 'Copyright 2014 Friedrich Paetzke'
